==> hermes-6.0.2.51.tar.gz: hermes-6.0.2.51/app/services/batch_tasks/base.rb <==
module BatchTasks
  class Base

    def initialize(log_name = nil)
      @log_lines ||= []
      @log_name = log_name
    end 

    def log_lines
      @log_lines
    end 

    def update_log_lines(lines)
      @log_lines = lines
    end

    def log_is_csv?
      @log_name&.end_with?('.csv')
    end 

    def create_log_doc(tagset_id)
      message = "#{Time.now} Creating a doc from the log on the tagset #{tagset_id}"
      message = [message] if log_is_csv?

      add_to_log_file(message, true)
      puts "File named <b>#{@log_name}</b> created on the server <b>#{Socket.gethostname}</b><br/>"

      doc = Doc.create(type: "file", title: @log_name, tagset_ids: tagset_id ? [tagset_id] : [])

      File.open(@log_name, 'r') do |file|
        doc.blob = file.read
      end

      if doc.save
        File.delete(@log_name) if File.exist?(@log_name)
        puts "Deleted file on the server after the successfull document save.<br/><a target='_blank' href='/documents/#{doc.id}'>Link to the document</a><br/>"
      else
        puts "Failed to save document: #{doc.errors.full_messages.join(', ')}<br/>"
        puts "The log is still on the server.<br/>"
      end 
      
      doc
    rescue => e
      puts "Error :#{e}<br/>"
      puts "The log is still on the server.<br/>"
    end

    def add_to_log_file(line, force_flush = false)
      @log_lines ||= []
      @log_lines << line

      if @log_lines.length >= 1000 || force_flush
        if log_is_csv?
          CSV.open("./#{@log_name}", 'ab', col_sep: ";") do |csv|
            @log_lines.each do |line|
              csv << line
            end
          end
        else
          File.open(@log_name, "a:UTF-8") do |file|
            @log_lines.each do |content|
              file.write(content + "\n")
            end
          end
        end

        @log_lines.clear
      end
    end

    def print_time(time)
      time.utc.strftime('%Y-%m-%d-%H:%M:%S')
    end 

    private

    def enqueue_notifications(notif_hash, key)
      notification_nb = 0
    
      notif_hash.each do |housing_request_id, offer_ids|
        begin
          hr_attributes = Hermes::HousingRequest.where(id: housing_request_id).pluck(:id, :requester_firstname, :requester_lastname, :user_id)&.first
          next unless hr_attributes

          user = User.find(hr_attributes[3])
          user.notify(
            key: NOTIFICATION_KEYS[:user][key],
            channels: ['email'],
            datas: {
              first_name: hr_attributes[1],
              last_name: hr_attributes[2], 
              offer_ids: offer_ids
            },
            is_slow: true
          )
          
          notification_nb += 1
          add_to_log_file("Created notications for #{hr_attributes[0]} #{user.email} with offers: #{offer_ids.join(', ')}")
        rescue => exception
          add_to_log_file("housing_request_id : #{hr_attributes[0]} => #{exception}")
        end
      end 
    
      notification_nb
    end 
  end
end

==> hermes-6.0.3.14.tar.gz: hermes-6.0.3.14/app/services/batch_tasks/base.rb <==
module BatchTasks
  class Base

    def initialize(log_name = nil)
      @log_lines ||= []
      @log_name = log_name
    end 

    def log_lines
      @log_lines
    end 

    def update_log_lines(lines)
      @log_lines = lines
    end

    def log_is_csv?
      @log_name&.end_with?('.csv')
    end 

    def create_log_doc(tagset_id)
      message = "#{Time.now} Creating a doc from the log on the tagset #{tagset_id}"
      message = [message] if log_is_csv?

      add_to_log_file(message, true)
      puts "File named <b>#{@log_name}</b> created on the server <b>#{Socket.gethostname}</b><br/>"

      doc = Doc.create(type: "file", title: @log_name, tagset_ids: tagset_id ? [tagset_id] : [])

      File.open(@log_name, 'r') do |file|
        doc.blob = file.read
      end

      if doc.save
        File.delete(@log_name) if File.exist?(@log_name)
        puts "Deleted file on the server after the successfull document save.<br/><a target='_blank' href='/documents/#{doc.id}'>Link to the document</a><br/>"
      else
        puts "Failed to save document: #{doc.errors.full_messages.join(', ')}<br/>"
        puts "The log is still on the server.<br/>"
      end 
      
      doc
    rescue => e
      puts "Error :#{e}<br/>"
      puts "The log is still on the server.<br/>"
    end

    def add_to_log_file(line, force_flush = false)
      @log_lines ||= []
      @log_lines << line

      if @log_lines.length >= 1000 || force_flush
        if log_is_csv?
          CSV.open("./#{@log_name}", 'ab', col_sep: ";") do |csv|
            @log_lines.each do |line|
              csv << line
            end
          end
        else
          File.open(@log_name, "a:UTF-8") do |file|
            @log_lines.each do |content|
              file.write(content + "\n")
            end
          end
        end

        @log_lines.clear
      end
    end

    def print_time(time)
      time.utc.strftime('%Y-%m-%d-%H:%M:%S')
    end 

    private

    def enqueue_notifications(notif_hash, key)
      notification_nb = 0
    
      notif_hash.each do |housing_request_id, offer_ids|
        begin
          hr = Hermes::HousingRequest.find_by(id: housing_request_id)
          next unless hr

          hr.user.notify(
            key: NOTIFICATION_KEYS[:user][key],
            channels: ['email'],
            datas: {
              offer_ids: offer_ids
            },
            is_slow: true
          )
          
          notification_nb += 1
          add_to_log_file("Created notications for #{hr.id} #{hr.user.find_email_for_notification(key, hr)} with offers: #{offer_ids.join(', ')}")
        rescue => exception
          add_to_log_file("housing_request_id : #{hr.id} => #{exception}")
        end
      end 
    
      notification_nb
    end 
  end
end
